<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package Crimson Lite
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function crimson_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'crimson_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 */
function crimson_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}
	
	$header_options = get_option('crimson_general_settings');
	if($header_options['color_scheme'])
		$classes[] = $header_options['color_scheme'].'-skin';

	return $classes;
}
add_filter( 'body_class', 'crimson_body_classes' );

/**
 * Adds custom classes to the array of body classes.
 */
function crimson_post_classes( $classes ) {
	global $post;
	if(has_post_thumbnail($post->ID)){
		$classes[] = 'has-thumb';
		$classes[] = 'clearfix';
	}
	return $classes;
}
add_filter( 'post_class', 'crimson_post_classes' );

/**
 * Filter in a link to a content ID attribute for the next/previous image links on image attachment pages
 */
function crimson_enhanced_image_navigation( $url, $id ) {
	if ( ! is_attachment() && ! wp_attachment_is_image( $id ) )
		return $url;

	$image = get_post( $id );
	if ( ! empty( $image->post_parent ) && $image->post_parent != $id )
		$url .= '#main';

	return $url;
}
add_filter( 'attachment_link', 'crimson_enhanced_image_navigation', 10, 2 );

/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 */
function crimson_wp_title( $title, $sep ) {
	global $page, $paged;

	if ( is_feed() )
		return $title;

	// Add the blog name
	$title .= get_bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title .= " $sep $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		$title .= " $sep " . sprintf( __( 'Page %s', 'crimson' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'crimson_wp_title', 10, 2 );

function crimson_excerpt_more($more) {
    global $post;
	return '<a class="moretag" href="'. get_permalink($post->ID) . '"><span>Read More</span></a>';
}
add_filter('excerpt_more', 'crimson_excerpt_more');

function crimson_credit_links($type){
	if($type == 'nofollow') 
		_e('Theme by <a href="http://wpgurus.net/" rel="nofollow">WP Gurus</a>', 'crimson');
	elseif(($type == 'homepage' && !is_front_page()) || $type == 'hide')
		return;
	else
		_e('Theme by <a href="http://wpgurus.net/">WP Gurus</a>', 'crimson');
}